@@ -1,6 +1,3 @@
-## ---- echo = FALSE, message = FALSE--------------------------------------
-knitr::opts_chunk$set(comment = "")
-
 ## ------------------------------------------------------------------------
 library("devtools")
 
