@@ -1,6 +1,6 @@
 library("testthat")
 library("msgtools")
 
-if (check_for_gettext()) {
+if (!grepl('SunOS',Sys.info()['sysname']) && check_for_gettext()) {
     test_check("msgtools", reporter = "summary")
 }
